<?php

/**
 * @file
 * Provide and handle a Resave All Nodes form.
 */

/**
 * Resave All Nodes form.
 *
 * @param array $form
 *   Nested array of form elements.
 * @param array $form_state
 *   A keyed array containing the current state of the form.
 *
 * @return array
 *   The Resave All Nodes form.
 */
function resave_all_nodes_form(array $form, array &$form_state) {
  $options = node_type_get_names();

  $form['node_types'] = [
    '#type' => 'checkboxes',
    '#title' => t('Content types'),
    '#description' => t('If none selected all nodes of all types will be resaved.'),
    '#options' => $options,
  ];

  $form['available_node_types'] = [
    '#type' => 'hidden',
    '#value' => $options,
  ];

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Resave now'),
  ];

  return $form;
}

/**
 * Resave All Nodes form submit handler.
 *
 * @param array $form
 *   Nested array of form elements.
 * @param array $form_state
 *   A keyed array containing the current state of the form.
 */
function resave_all_nodes_form_submit(array $form, array &$form_state) {
  $available_node_types = $form_state['values']['available_node_types'];
  $selected_node_types = $form_state['values']['node_types'];

  $node_types = !empty(array_filter($selected_node_types)) ? array_filter(array_values($selected_node_types)) : array_keys($available_node_types);

  module_load_include('inc', 'node', 'node.admin');
  $nids = _resave_all_nodes_get_node_ids($node_types);
  node_mass_update($nids, []);
}

/**
 * @param array $node_types
 *   An array of node type machine names.
 *
 * @return array
 *   An array of node IDs.
 */
function _resave_all_nodes_get_node_ids(array $node_types) {
  $query = $query = new EntityFieldQuery();
  $result = $query->entityCondition('entity_type', 'node')
    ->entityCondition('bundle', $node_types, 'IN')
    ->execute();
  $nids = array_keys($result['node']);

  return $nids;
}
